testing
library
Classes
-
RoutedRequestHandler
-
Adapter for the Routed Engine that conforms to the RequestHandler interface.
Functions
-
engineGroup(String description, {required void define(Engine engine, TestClient client, EngineTestFunction ), Engine? engine, TransportMode transportMode = TransportMode.inMemory, EngineConfig? engineConfig, List<EngineOpt>? options, List<ServiceProvider>? providers})
→ void
-
Creates a group of tests with shared engine configuration
-
engineTest(String description, TestCallback callback, {Engine? engine, TransportMode transportMode = TransportMode.inMemory, EngineConfig? engineConfig, List<EngineOpt>? options, List<ServiceProvider>? providers, bool autoCloseEngine = false})
→ void
-
Defines a single test that runs with a dedicated
Engine and TestClient.
Typedefs
-
EngineTestFunction
= void Function(String description, TestCallback callback)
-
A callback function used by the
engineGroup helper to define tests within
the group.
-
TestCallback
= Future<void> Function(Engine engine, TestClient client)
-
A callback function used by the
engineTest helper.
It receives the Engine and TestClient instances for the test.